package SPVM::HTTP::Minimal::Socket;

1;

=head1 Name

SPVM::HTTP::Minimal::Socket - Socket for HTTP

=head1 Description

The HTTP::Minimal::Socket class of L<SPVM> has methods to manipulate a socket for HTTP.

=head1 Usage

  use HTTP::Minimal::Socket;

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

