package SPVM::HTTP::Minimal::URL;



1;

=head1 Name

SPVM::HTTP::Minimal::URL - URL

=head1 Description

The HTTP::Minimal::URL class of L<SPVM> has methods to manipulate URL.

=head1 Usage

  use HTTP::Minimal::URL;

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

